@@ -4,7 +4,7 @@
  * Gnome Chemisty Utils
  * crystaldoc.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -39,8 +39,7 @@
 
 using namespace gcu;
 
-gchar const *LatticeName[] = {
-	"simple cubic",
+gchar *LatticeName[] = {"simple cubic",
 	"body-centered cubic",
 	"face-centered cubic",
 	"hexagonal",
@@ -53,8 +52,7 @@ gchar const *LatticeName[] = {
 	"rhombohedral",
 	"monoclinic",
 	"base-centered monoclinic",
-	"triclinic"
-};
+	"triclinic"};
 
 CrystalDoc::CrystalDoc()
 {
@@ -155,7 +153,8 @@ void CrystalDoc::ParseXMLTree (xmlNode* xml)
 	}
 	node = xml->children;
 	while(node) {
-		if (!strcmp ((gchar*) node->name, "lattice")) {
+		if (!strcmp ((gchar*) node->name, "text"));
+		else if (!strcmp ((gchar*) node->name, "lattice")) {
 			txt = (char*) xmlNodeGetContent (node);
 			int i = 0;
 			while (strcmp (txt, LatticeName[i]) && (i < 14))
@@ -540,7 +539,7 @@ xmlDocPtr CrystalDoc::BuildXMLTree()
 	
 	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 	setlocale(LC_NUMERIC, "C");
-	xml->children =  xmlNewDocNode(xml, NULL, (xmlChar*)"crystal", NULL);
+	xmlDocSetRootElement (xml,  xmlNewDocNode(xml, NULL, (xmlChar*)"crystal", NULL));
 	
 	try
 	{
